# vim:ft=perl
# Copyright (c) 2005-2008 Zmanda Inc.  All Rights Reserved.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 2 as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
# or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# Contact information: Zmanda Inc, 465 S Mathlida Ave, Suite 300
# Sunnyvale, CA 94086, USA, or: http://www.zmanda.com

package Amanda::Constants;

=head1 NAME

Amanda::Constants - perl access to build-time configuration values

=head1 SYNOPSIS

  use Amanda::Constants;

  my $default_config = $Amanda::Constants::DEFAULT_CONFIG;

This package is a means of getting all of the necessary variables
provided by configure into Perl scripts, without a bunch of
boilerplate, and without requiring config.status substitution for
every .pm file.  

This module does not automatically export any of its values.

See the source for the list of constants available.

=head1 API STATUS

Constants will not be removed from this file unless they are no longer available in the codebase.

=cut

# the 'warnings' pragma doesn't recognized exported variables as "used", and generates warnings
# for variables only used once.  We turn it off for this module.
no warnings;

# (keep this list sorted in alphabetical order, for ease of updates)

$AIX_BACKUP = "";
$AMANDA_DEBUG_DAYS = "4";
$ASSERTIONS = "";
$BSDTCP_SECURITY = "yes";
$BSDUDP_SECURITY = "yes";
$BSD_SECURITY = "yes";
$CC = "cc";
$CHECK_USERID = "1";
$CLIENT_HOST_INSTANCE = "HOSTNAME_INSTANCE";
$CLIENT_HOST_KEY_FILE = "KEYFILE";
$CLIENT_HOST_PRINCIPAL = "rcmd";
$CLIENT_LOGIN = "operator";
$COMPRESS_BEST_OPT = "--best";
$COMPRESS_FAST_OPT = "--fast";
$COMPRESS_PATH = "/usr/bin/gzip";
$COMPRESS_SUFFIX = ".gz";
$DEFAULT_AMANDATES_FILE = "/usr/local/var/amanda/amandates";
$DEFAULT_CONFIG = "DailySet1";
$DEFAULT_SERVER = "localhost";
$DEFAULT_TAPE_DEVICE = "";
$DEFAULT_TAPE_SERVER = "localhost";
$DUMP = "/sbin/dump";
$DUMP_RETURNS_1 = "";
$GNUTAR = "/usr/local/bin/gtar";
$HAVE_GZIP = "1";
$KRB4_SECURITY = "no";
$KRB5_SECURITY = "no";
$LOCKING = "LNLOCK";
$MAILER = "/usr/bin/Mail";
$RESTORE = "/sbin/restore";
$PS = "/bin/ps";
$PS_ARGUMENT = "-axo pid,ppid,command";
$RSH_SECURITY = "no";
$SAMBA_CLIENT = "";
$SERVER_HOST_INSTANCE = "amanda";
$SERVER_HOST_KEY_FILE = "/.amanda";
$SERVER_HOST_PRINCIPAL = "amanda";
$SSH_SECURITY = "yes";
$STAR = "@STAR@";
$TICKET_LIFETIME = "128";
$UNCOMPRESS_OPT = "-dc";
$UNCOMPRESS_PATH = "/usr/bin/gzip";
$USE_AMANDAHOSTS = "yes";
$USE_RUNDUMP = "";
$USE_VERSION_SUFFIXES = "no";
$VDUMP = "";
$VERSION = "2.6.1p2";
$VRESTORE = "";
$VXDUMP = "";
$VXRESTORE = "";
$XFSDUMP = "";
$XFSRESTORE = "";

1;
